@@ -11,9 +11,13 @@ multivariate Matrix for lmpy operations.'''
 
 
 # .....................................................................................
-def cli():
-    """Command-line interface to build shapegrid."""
-    parser = argparse.ArgumentParser(description=DESCRIPTION)
+def build_parser():
+    """Build an argparse.ArgumentParser object for the tool.
+
+    Returns:
+        argparse.ArgumentParser: An argument parser for the tool's parameters.
+    """
+    parser = argparse.ArgumentParser(prog='build_shapegrid', description=DESCRIPTION)
     parser.add_argument('--config_file', type=str, help='Path to configuration file.')
     parser.add_argument(
         'shapegrid_filename',
@@ -32,6 +36,13 @@ def cli():
     parser.add_argument(
         'epsg', type=int, help='The EPSG code (map projection) for the shapegrid.'
     )
+    return parser
+
+
+# .....................................................................................
+def cli():
+    """Command-line interface to build shapegrid."""
+    parser = build_parser()
     args = _process_arguments(parser, config_arg='config_file')
     cell_sides = 4  # Add this to parameters if we enable hexagons again
     build_shapegrid(
@@ -47,7 +58,7 @@ def cli():
 
 
 # .....................................................................................
-__all__ = ['build_shapegrid', 'cli']
+__all__ = ['build_parser', 'build_shapegrid', 'cli']
 
 
 # .....................................................................................
