@@ -6,18 +6,18 @@ from lmpy.data_preparation.layer_encoder import LayerEncoder
 from lmpy.tools._config_parser import _process_arguments
 
 
+# .....................................................................................
 DESCRIPTION = 'Encode raster and / or vector layers into a site by layer matrix.'
 
 
 # .....................................................................................
-def cli():
-    """Command line interface for layer encoding.
+def build_parser():
+    """Build an argparse.ArgumentParser object for the tool.
 
-    Raises:
-        ValueError: Raised if an unknown encoding method is provided or too many layer
-            arguments.
+    Returns:
+        argparse.ArgumentParser: An argument parser for the tool's parameters.
     """
-    parser = argparse.ArgumentParser(description=DESCRIPTION)
+    parser = argparse.ArgumentParser(prog='encode_layers', description=DESCRIPTION)
     parser.add_argument('--config_file', type=str, help='Path to configuration file.')
     parser.add_argument(
         '--encode_method',
@@ -63,6 +63,18 @@ def cli():
         action='append',
         help='File location of layer [ LABEL [ ATTRIBUTE FIELD ]].',
     )
+    return parser
+
+
+# .....................................................................................
+def cli():
+    """Command line interface for layer encoding.
+
+    Raises:
+        ValueError: Raised if an unknown encoding method is provided or too many layer
+            arguments.
+    """
+    parser = build_parser()
 
     args = _process_arguments(parser, config_arg='config_file')
 
@@ -119,7 +131,7 @@ def cli():
 
 
 # .....................................................................................
-__all__ = ['cli']
+__all__ = ['build_parser', 'cli']
 
 
 # .....................................................................................
