@@ -32,9 +32,13 @@ def wrangle_tree(tree, wranglers):
 
 
 # .....................................................................................
-def cli():
-    """Command-line interface for the tool."""
-    parser = argparse.ArgumentParser(description=DESCRIPTION)
+def build_parser():
+    """Build an argparse.ArgumentParser object for the tool.
+
+    Returns:
+        argparse.ArgumentParser: An argument parser for the tool's parameters.
+    """
+    parser = argparse.ArgumentParser(prog='wrangle_tree', description=DESCRIPTION)
     parser.add_argument('--config_file', type=str, help='Path to configuration file.')
     parser.add_argument(
         '-r', '--report_filename', type=str, help='Path to write report.'
@@ -62,6 +66,13 @@ def cli():
         choices=['newick', 'nexus'],
         help='The schema of the output phylogenetic tree.',
     )
+    return parser
+
+
+# .....................................................................................
+def cli():
+    """Command-line interface for the tool."""
+    parser = build_parser()
     args = _process_arguments(parser, config_arg='config_file')
     tree = TreeWrapper.get(path=args.tree_filename, schema=args.tree_schema)
     with open(args.wrangler_configuration_file, mode='rt') as in_json:
